@@ -5,7 +5,7 @@ use warnings;
 
 BEGIN {
 ### after: 	push @INC, qw(@RT_LIB_PATH@);
-	push @INC, qw(/opt/rt3/local/lib /opt/rt3/lib);
+	push @INC, qw(/opt/3.5-TESTING/local/lib /opt/3.5-TESTING//lib);
 }
 
 1;
